==> sl-2.32.1.zip: sl/date.lang.php <==
<?php
/**
 * @package Dotclear
 *
 * @copyright Olivier Meunier & Association Dotclear
 */
#
# DOT NOT MODIFY THIS FILE !
#

use Dotclear\Helper\L10n;

L10n::$locales['%Y-%m-%d %H:%M'] = '%Y-%m-%d %H:%M';
L10n::$locales['_Jan'] = '_jan';
L10n::$locales['_Feb'] = '_feb';
L10n::$locales['_Mar'] = '_mar';
L10n::$locales['_Apr'] = '_apr';
L10n::$locales['_May'] = '_maj';
L10n::$locales['_Jun'] = '_Jun';
L10n::$locales['_Jul'] = '_jul';
L10n::$locales['_Aug'] = '_avg';
L10n::$locales['_Sep'] = '_ sep';
L10n::$locales['_Oct'] = '_okt';
L10n::$locales['_Nov'] = '_ nov';
L10n::$locales['_Dec'] = '_dec';
L10n::$locales['January'] = 'januarja';
L10n::$locales['February'] = 'februar';
L10n::$locales['March'] = 'marec';
L10n::$locales['April'] = 'aprila';
L10n::$locales['May'] = 'maja';
L10n::$locales['June'] = 'junija';
L10n::$locales['July'] = 'julija';
L10n::$locales['August'] = 'avgusta';
L10n::$locales['September'] = 'septembra';
L10n::$locales['October'] = 'oktobra';
L10n::$locales['November'] = 'novembra';
L10n::$locales['December'] = 'decembra';
L10n::$locales['_Mon'] = '_pon';
L10n::$locales['_Tue'] = '_tor';
L10n::$locales['_Wed'] = '_sre';
L10n::$locales['_Thu'] = '_čet';
L10n::$locales['_Fri'] = '_pet';
L10n::$locales['_Sat'] = '_sob';
L10n::$locales['_Sun'] = '_Sonce';
L10n::$locales['Monday'] = 'ponedeljek';
L10n::$locales['Tuesday'] = 'torek';
L10n::$locales['Wednesday'] = 'sreda';
L10n::$locales['Thursday'] = 'četrtek';
L10n::$locales['Friday'] = 'Petek';
L10n::$locales['Saturday'] = 'sobota';
L10n::$locales['Sunday'] = 'nedelja';

==> sl-2.37-dev-r20260119.1443.zip: sl/date.lang.php <==
<?php
/**
 * @package Dotclear
 *
 * @copyright Olivier Meunier & Association Dotclear
 */
#
# DOT NOT MODIFY THIS FILE !
#

use Dotclear\Helper\L10n;

L10n::$locales['%Y-%m-%d %H:%M'] = '%Y-%m-%d %H:%M';
L10n::$locales['_Jan'] = 'jan';
L10n::$locales['_Feb'] = 'feb';
L10n::$locales['_Mar'] = 'mar';
L10n::$locales['_Apr'] = 'apr';
L10n::$locales['_May'] = 'maj';
L10n::$locales['_Jun'] = 'jun';
L10n::$locales['_Jul'] = 'jul';
L10n::$locales['_Aug'] = 'avg';
L10n::$locales['_Sep'] = 'sep';
L10n::$locales['_Oct'] = 'okt';
L10n::$locales['_Nov'] = 'nov';
L10n::$locales['_Dec'] = 'dec';
L10n::$locales['January'] = 'januarja';
L10n::$locales['February'] = 'februar';
L10n::$locales['March'] = 'marec';
L10n::$locales['April'] = 'aprila';
L10n::$locales['May'] = 'maja';
L10n::$locales['June'] = 'junija';
L10n::$locales['July'] = 'julija';
L10n::$locales['August'] = 'avgusta';
L10n::$locales['September'] = 'septembra';
L10n::$locales['October'] = 'oktobra';
L10n::$locales['November'] = 'novembra';
L10n::$locales['December'] = 'decembra';
L10n::$locales['_Mon'] = 'pon';
L10n::$locales['_Tue'] = 'tor';
L10n::$locales['_Wed'] = 'sre';
L10n::$locales['_Thu'] = 'čet';
L10n::$locales['_Fri'] = 'pet';
L10n::$locales['_Sat'] = 'sob';
L10n::$locales['_Sun'] = 'sonce';
L10n::$locales['Monday'] = 'ponedeljek';
L10n::$locales['Tuesday'] = 'torek';
L10n::$locales['Wednesday'] = 'sreda';
L10n::$locales['Thursday'] = 'četrtek';
L10n::$locales['Friday'] = 'Petek';
L10n::$locales['Saturday'] = 'sobota';
L10n::$locales['Sunday'] = 'nedelja';
